.. _faq:

#################################
Frequently asked questions (FAQ) 
#################################

.. _faq_preference_file:

Where are the preference files saved?
=====================================
The main application preference file is saved in a hidden directory called `.masai` 
located in your home user directory. 

On Mac OSX system you access to this file by typing in the terminal::

	$ cd ~/.masai
	$ open masai.ini

On Linux system, the second command can be replaced by::

	$ vim masai.ini
	
or whatever you prefer to read and edit a text file.